@@ -81,6 +81,14 @@ class FlaviusBase:
         with request.urlopen(req, data=query, context=self.ssl_ctx) as response:
             return json.loads(response.read().decode('utf-8'))
 
+    def delete(self, query=None):
+        query = self.make_data(query=query)
+        headers = self.make_request_headers(len(query))
+        req = self.request(headers=headers, func='delete')
+
+        with request.urlopen(req, data=query, context=self.ssl_ctx) as response:
+            return json.loads(response.read().decode('utf-8'))
+
 
 class FlaviusBackData(FlaviusBase):
     """
